@@ -22,7 +22,11 @@ switchGRP <- function(x, na.last = TRUE, decreasing = FALSE, starts = FALSE,
   .Call(C_radixsort, na.last, decreasing, starts, group.sizes, sort, z)
 }
 
-group <- function(x, starts = FALSE, group.sizes = FALSE) `oldClass<-`(.Call(C_group, x, starts, group.sizes), c("qG", "na.included"))
+group <- function(x, starts = FALSE, group.sizes = FALSE) {
+  g <- .Call(C_group, x, starts, group.sizes)
+  oldClass(g) <- c("qG", "na.included")
+  g
+}
 
 gsplit <- function(x = NULL, g, use.g.names = FALSE, ...) {
   if(!(is.list(g) && inherits(g, "GRP"))) g <- GRP(g, return.groups = use.g.names, call = FALSE, ...)
@@ -273,6 +277,8 @@ finteraction <- function(..., factor = TRUE, ordered = FALSE, sort = factor, met
   res
 }
 
+itn <- function(...) finteraction(...)
+
 GRP.qG <- function(X, ..., group.sizes = TRUE, return.groups = TRUE, call = TRUE) {
   # if(!missing(...)) unused_arg_action(match.call(), ...)
   gvars <- l1orlst(as.character(substitute(X))) # paste(all.vars(call), collapse = ".") # good in all circumstances ?
@@ -348,14 +354,14 @@ GRP.pseries <- function(X, effect = 1L, ..., group.sizes = TRUE, return.groups =
 GRP.pdata.frame <- function(X, effect = 1L, ..., group.sizes = TRUE, return.groups = TRUE, call = TRUE)
   GRP.pseries(X, effect, ..., group.sizes = group.sizes, return.groups = return.groups, call = call)
 
-fgroup_by <- function(.X, ..., sort = TRUE, decreasing = FALSE, na.last = TRUE, return.order = sort, method = "auto") {          #   e <- substitute(list(...)) # faster but does not preserve attributes of unique groups !
+fgroup_by <- function(.X, ..., sort = TRUE, decreasing = FALSE, na.last = TRUE, return.groups = TRUE, return.order = sort, method = "auto") {          #   e <- substitute(list(...)) # faster but does not preserve attributes of unique groups !
   clx <- oldClass(.X)
   oldClass(.X) <- NULL
   m <- match(c("GRP_df", "grouped_df", "data.frame"), clx, nomatch = 0L)
   dots <- substitute(list(...))
-  vars <- all.vars(dots, unique = FALSE)
-  # In case sequences of columns are passed...
-  if(length(vars)+1L != length(dots) && any(all.names(dots) == ":")) {
+  # vars <- all.vars(dots, unique = FALSE)
+  # In case sequences of columns are passed... Think: can enable fgroup_by(mtcars, 1:cyl)
+  if(any(all_funs(dots) == ":")) { # length(vars)+1L != length(dots) && any(all.names(dots) == ":")
   # Note that fgroup_by(mtcars, bla = round(mpg / cyl), vs:am) only groups by vs, and am. fselect(mtcars, bla = round(mpg / cyl), vs:am) also does the wrong thing.
     nl <- `names<-`(as.vector(seq_along(.X), "list"), names(.X))
     vars <- eval(substitute(c(...)), nl, parent.frame())
@@ -369,8 +375,11 @@ fgroup_by <- function(.X, ..., sort = TRUE, decreasing = FALSE, na.last = TRUE,
   } else {
     e <- eval(dots, .X, parent.frame())
     name <- names(e)
-    # If something else than NSE cols is supplied
-    if(length(e) == 1L && length(e[[1L]]) != length(.X[[1L]]) && is.null(name)) {
+    vars <- all.vars(dots, unique = FALSE)
+    # If something else than NSE cols is supplied, see https://github.com/SebKrantz/collapse/issues/320
+    # Note: doesn't support fgroup_by(mtcars, cyl / vs), but ok, this should be named...
+    # fgroup_by(mtcars, c("cyl", "vs")) gives vars == character(0)
+    if(length(e) == 1L && is.null(name) && (length(vars) != 1L || !anyv(names(.X), vars))) { # !is.symbol(dots[[2L]]) || length(e[[1L]]) != length(.X[[1L]]) || is.function(e[[1L]] # Fixes #320
       e <- .X[cols2int(e[[1L]], .X, names(.X), FALSE)]
     } else {
       if(length(name)) {  # fgroup_by(mtcars, bla = round(mpg / cyl), vs, am)
@@ -379,7 +388,7 @@ fgroup_by <- function(.X, ..., sort = TRUE, decreasing = FALSE, na.last = TRUE,
       } else names(e) <- vars
     }
   }
-  attr(.X, "groups") <- GRP.default(e, NULL, sort, decreasing, na.last, TRUE, return.order, method, FALSE)
+  attr(.X, "groups") <- GRP.default(e, NULL, sort, decreasing, na.last, return.groups, return.order, method, FALSE)
   # if(any(clx == "sf")) oldClass(.X) <- clx[clx != "sf"]
   # attr(.X, "groups") <- GRP.default(fselect(if(m[2L]) fungroup(.X) else .X, ...), NULL, sort, decreasing, na.last, TRUE, return.order, method, FALSE)
     # Needed: wlddev %>% fgroup_by(country) gives error if dplyr is loaded. Also sf objects etc..
@@ -781,6 +790,21 @@ funique.data.frame <- function(x, cols = NULL, sort = FALSE, method = "auto", ..
   res
 }
 
+## Problem: could be confused to mean unique values within groups. Also can use ffirst() to achieve something similar
+# funique.grouped_df <- function(x, ...) {
+#   g <- GRP.grouped_df(x, call = FALSE)
+#   if(g[[1L]] == length(g[[2L]])) return(fungroup(x))
+#   st <- if(length(g$group.starts)) g$group.starts else .Call(C_ffirst, seq_along(g[[2L]]), g[[1L]], g[[2L]], NULL, FALSE)
+#   rn <- attr(x, "row.names")
+#   attr(x, "groups") <- NULL
+#   oldClass(x) <- fsetdiff(oldClass(x), c("GRP_df", "grouped_df"))
+#   res <- .Call(C_subsetDT, x, st, seq_along(unclass(x)), FALSE)
+#   if(is.numeric(rn) || is.null(rn) || rn[1L] == "1") return(res)
+#   attr(res, "row.names") <- Csv(rn, st)
+#   res
+# }
+
+
 funique.list <- function(x, cols = NULL, sort = FALSE, method = "auto", ...) funique.data.frame(x, cols, sort, method, ...)
 
 funique.sf <- function(x, cols = NULL, sort = FALSE, method = "auto", ...) {
