@@ -60,7 +60,7 @@ static int order = 1;
 static SEXP *saveds = NULL;
 static R_len_t *savedtl = NULL, nalloc = 0, nsaved = 0;
 
-static void savetl_init()
+static void savetl_init(void)
 {
   if (nsaved || nalloc || saveds || savedtl)
     error("Internal error: savetl_init checks failed (%d %d %p %p).",
@@ -77,7 +77,7 @@ static void savetl_init()
   }
 }
 
-static void savetl_end()
+static void savetl_end(void)
 {
   // Can get called if nothing has been saved yet (nsaved == 0), or
   // even if _init() has not been called yet (pointers NULL). Such as
@@ -160,7 +160,7 @@ static void mpush(int x, int n)
     gsmax[flip] = x;
 }
 
-static void flipflop()
+static void flipflop(void)
 {
   flip = 1 - flip;
   gsngrp[flip] = 0;
@@ -169,7 +169,7 @@ static void flipflop()
     growstack((uint64_t)(gsalloc[1 - flip]) * 2);
 }
 
-static void gsfree()
+static void gsfree(void)
 {
   free(gs[0]);
   free(gs[1]);
@@ -1717,8 +1717,9 @@ SEXP Cradixsort(SEXP NA_last, SEXP decreasing, SEXP RETstrt, SEXP RETgs, SEXP SO
 
   int maxgrpn = gsmax[flip];   // biggest group in the first arg
   void *xsub = NULL;           // local
-  int (*f) ();
-  void (*g) ();
+  // int (*f) ();
+  // void (*g) ();
+  int fgtype;
 
   if (narg > 1 && gsngrp[flip] < n) {
     // double is the largest type, 8
@@ -1746,26 +1747,31 @@ SEXP Cradixsort(SEXP NA_last, SEXP decreasing, SEXP RETstrt, SEXP RETgs, SEXP SO
     switch (TYPEOF(x)) {
     case INTSXP:
     case LGLSXP:
-      f = &isorted;
-      g = &isort;
+      // f = &isorted;
+      // g = &isort;
+      fgtype = 1;
       break;
     case REALSXP:
       twiddle = &dtwiddle;
       is_nan = &dnan;
-      f = &dsorted;
-      g = &dsort;
+      // f = &dsorted;
+      // g = &dsort;
+      fgtype = 2;
       break;
     case STRSXP:
-      f = &csorted;
+      // f = &csorted;
+      fgtype = 3;
       if (sortStr) {
         csort_pre(xd, n);
         alloc_csort_otmp(gsmax[1 - flip]);
-        g = &csort;
+      //  g = &csort;
       }
       // no increasing/decreasing order required if sortStr = FALSE,
       // just a dummy argument
-      else
-        g = &cgroup;
+      else {
+      //  g = &cgroup;
+      fgtype = 4;
+      }
       break;
     default:
       Error("Arg %d is type '%s', not yet supported",
@@ -1830,7 +1836,18 @@ SEXP Cradixsort(SEXP NA_last, SEXP decreasing, SEXP RETstrt, SEXP RETgs, SEXP SO
       // continue; // BASELINE short circuit timing
       // point. Up to here is the cost of creating xsub.
       // [i|d|c]sorted(); very low cost, sequential
-      tmp = (*f)(xsub, thisgrpn);
+      // tmp = (*f)(xsub, thisgrpn);
+      switch(fgtype) {
+      case 1:
+        tmp = isorted(xsub, thisgrpn);
+        break;
+      case 2:
+        tmp = dsorted(xsub, thisgrpn);
+        break;
+      case 3:
+      case 4:
+        tmp = csorted(xsub, thisgrpn);
+      }
       if (tmp) {
         // *sorted will have already push()'d the groups
         if (tmp == -1) {
@@ -1857,7 +1874,13 @@ SEXP Cradixsort(SEXP NA_last, SEXP decreasing, SEXP RETstrt, SEXP RETgs, SEXP SO
       newo[0] = -1;
       // may update osub directly, or if not will put the
       // result in global newo
-      (*g)(xsub, osub, thisgrpn);
+      // (*g)(xsub, osub, thisgrpn);
+      switch(fgtype) {
+      case 1: isort(xsub, osub, thisgrpn); break;
+      case 2: dsort(xsub, osub, thisgrpn); break;
+      case 3: csort(xsub, osub, thisgrpn); break;
+      case 4: cgroup(xsub, osub, thisgrpn); break;
+      }
 
       if (newo[0] != -1) {
         if (nalast != 0)
