@@ -1,21 +1,23 @@
 context("flag / L / F")
 
+if(!is.null(attributes(identical(FALSE, TRUE)))) stop("OECD label issue")
+
 # rm(list = ls())
 # TODO: test computations on irregular time series and panels
-
+set.seed(101)
 x <- abs(10*rnorm(100))
 xNA <- x
 xNA[sample.int(100, 20)] <- NA
 f <- as.factor(rep(1:10, each = 10))
 t <- as.factor(rep(1:10, 10))
 
-data <- wlddev[wlddev$iso3c %in% c("BLZ","IND","USA","SRB","GRL"), ]
+data <- setRownames(wlddev[wlddev$iso3c %in% c("BLZ","IND","USA","SRB","GRL"), ])
 g <- GRP(droplevels(data$iso3c))
 td <- as.factor(data$year)
 dataNA <- na_insert(data)
-m <- as.matrix(data)
+m <- qM(data)
 suppressWarnings(storage.mode(m) <- "numeric")
-mNAc <- as.matrix(dataNA)
+mNAc <- qM(dataNA)
 mNA <- mNAc
 suppressWarnings(storage.mode(mNA) <- "numeric")
 
@@ -31,7 +33,7 @@ o = order(o)
 od = order(rnorm(length(td)))
 muo = m[od, ]
 datauo = data[od, ]
-guo = as.factor_GRP(g)[od]
+guo = as_factor_GRP(g)[od]
 tduo = td[od]
 t2duo = seq_along(od)[od]
 od = order(od)
@@ -415,8 +417,8 @@ test_that("L.data.frame method is foolproof", {
   expect_visible(L(wlddev, -1:1,~iso3c, cols = NULL))
   expect_visible(L(wlddev, -1:1,wlddev$iso3c, wlddev$year, cols = NULL))
   expect_visible(L(wlddev, -1:1,~iso3c, ~year, cols = NULL))
-  expect_error(L(wlddev, cols = 9:13))
-  expect_error(L(wlddev, -1:1,~iso3c, ~year, cols = 9:13))
+  expect_error(L(wlddev, cols = 9:14))
+  expect_error(L(wlddev, -1:1,~iso3c, ~year, cols = 9:14))
   expect_error(L(wlddev, cols = c("PCGDP","LIFEEX","bla")))
   expect_error(L(wlddev, -1:1,~iso3c, ~year, cols = c("PCGDP","LIFEEX","bla")))
 
@@ -445,4 +447,3 @@ test_that("L.data.frame method is foolproof", {
 
 
 
-
