@@ -1,5 +1,9 @@
 context("fsummarise and fmutate")
 
+if(!is.null(attributes(identical(FALSE, TRUE)))) stop("OECD label issue")
+expect_equal(1, 1)
+
+if(requireNamespace("magrittr", quietly = TRUE) && requireNamespace("dplyr", quietly = TRUE)) {
 library(magrittr)
 
 bmean <- base::mean
@@ -7,11 +11,14 @@ bsum <- base::sum
 bsd <- stats::sd
 bmax <- base::max
 
+NCRAN <- identical(Sys.getenv("NCRAN"), "TRUE")
+
 mtc <- dplyr::as_tibble(mtcars)
 gmtc <- dplyr::group_by(mtc, cyl, vs, am)
 
 expect_equal(gsplit(mtcars$mpg, GRP(gmtc), TRUE), split(mtcars$mpg, as_factor_GRP(GRP(gmtc))))
 
+if(NCRAN) {
 
 test_that("fsummarise works like dplyr::summarise for tagged vector expressions", {
 
@@ -79,6 +86,19 @@ test_that("fsummarise works like dplyr::summarise for tagged vector expressions"
  expect_false(all_obj_equal(smr(gmtc, mpg = fmean(log(mpg)) + bmax(qsec)),
               dplyr::summarise(gmtc, mpg = bmean(log(mpg)) + bmax(qsec), .groups = "drop")))
 
+ # Testing expressions turned into functions:
+ mid_fun <- function(x) (bmin(x) + bmax(x)) / 2
+ expect_true(all_obj_equal(smr(gmtc, mid_mpg = (bmin(mpg) + bmax(mpg)) / 2),
+                           smr(gmtc, mid_mpg = (fmin(mpg) + fmax(mpg)) / 2),
+                           smr(gmtc, mid_mpg = mid_fun(mpg)),
+              dplyr::summarise(gmtc, mid_mpg = (bmin(mpg) + bmax(mpg)) / 2, .groups = "drop")))
+
+ # Adding global variable:
+ expect_true(all_obj_equal(smr(gmtc, mid_mpg = (bmin(mpg) + bmax(mpg)) / 2 + q),
+                           smr(gmtc, mid_mpg = (fmin(mpg) + fmax(mpg)) / 2 + q),
+                           smr(gmtc, mid_mpg = mid_fun(mpg) + q),
+                           dplyr::summarise(gmtc, mid_mpg = (bmin(mpg) + bmax(mpg)) / 2 + q, .groups = "drop")))
+
  # Weighted computations
  expect_equal(smr(gmtc, mpg = weighted.mean(mpg, wt)), dplyr::summarise(gmtc, mpg = weighted.mean(mpg, wt), .groups = "drop"))
  expect_equal(smr(gmtc, mpg = fmean(mpg, wt)), dplyr::summarise(gmtc, mpg = fmean(mpg, w = wt), .groups = "drop"))
@@ -105,8 +125,12 @@ test_that("fsummarise works like dplyr::summarise for tagged vector expressions"
 
 })
 
+}
+
 wld <- dplyr::as_tibble(wlddev)
-gwld <- dplyr::group_by(wlddev, country)
+gwld <- dplyr::group_by(wlddev, iso3c)
+
+if(NCRAN) {
 
 test_that("fsummarise works like dplyr::summarise with across and simple usage", {
 
@@ -255,6 +279,7 @@ test_that("fsummarise works like dplyr::summarise with across and grouped usage"
 
 })
 
+}
 
 test_that("fsummarise miscellaneous things", {
 
@@ -271,23 +296,24 @@ test_that("fsummarise miscellaneous things", {
     rsplit(mtcars, disp + hp ~ cyl) %>% lapply(pwcorDF) %>% unlist2d("cyl", "var") %>% tfm(cyl = as.numeric(cyl))
   )
 
-  if(identical(Sys.getenv("NCRAN"), "TRUE")) # No tests depending on suggested package (except for major ones).
+  if(identical(Sys.getenv("LOCAL"), "TRUE")) # No tests depending on suggested package (except for major ones).
   expect_equal(
     mtcars %>% gby(cyl) %>% smr(acr(disp:hp, pwcorDF, w = wt, .apply = FALSE)),
     rsplit(mtcars, disp + hp + wt ~ cyl) %>% lapply(function(x) pwcorDF(gv(x, 1:2), w = x$wt)) %>%
       unlist2d("cyl", "var") %>% tfm(cyl = as.numeric(cyl))
   )
 
+  if(requireNamespace("data.table", quietly = TRUE)) {
   lmest <- function(x) list(Mods = list(lm(disp~., x)))
   expect_equal(
     qDT(mtcars) %>% gby(cyl) %>% smr(acr(disp:hp, lmest, .apply = FALSE)),
     qDT(mtcars) %>% rsplit(disp + hp ~ cyl) %>% lapply(lmest) %>% data.table::rbindlist(idcol = "cyl") %>%
       tfm(cyl = as.numeric(cyl))
   )
-
+  }
 })
 
-
+if(NCRAN) {
 
 test_that("fmutate works as intended for simple usage", {
 
@@ -322,6 +348,8 @@ test_that("fmutate works as intended for simple usage", {
 
 })
 
+}
+
 test_that("fmutate with across works like ftransformv", {
 
    expect_true(all_obj_equal(
@@ -361,6 +389,16 @@ test_that("fmutate with across works like ftransformv", {
 
 })
 
+test_that("fmutate with across reorders correctly", {
+
+  for(i in seq_col(wlddev)) {
+    expect_equal(fungroup(fmutate(fgroup_by(wlddev, i), across(c(PCGDP, LIFEEX), identity))), wlddev)
+    expect_equal(fungroup(fmutate(fgroup_by(wlddev, i), across(.fns = identity))), wlddev)
+  }
+
+})
+
+if(NCRAN) {
 
 test_that("fmutate miscellaneous", {
 
@@ -385,7 +423,7 @@ test_that("fmutate miscellaneous", {
 
   expect_equal(
     fmutate(mtcars, a = mpg, b = a + hp + disp, c = cyl, hp = wt + carb, .keep = "none"),
-    dplyr::mutate(mtcars, a = mpg, b = a + hp + disp, c = cyl, hp = wt + carb, .keep = "none")
+    dplyr::transmute(mtcars, a = mpg, b = a + hp + disp, c = cyl, hp = wt + carb)
   )
 
   expect_identical(names(fmutate(mtcars, a = mpg, b = a, c = cyl, hp = wt, .keep = "unused")), c(setdiff(names(mtcars), .c(mpg, cyl, wt)), letters[1:3]))
@@ -403,7 +441,7 @@ test_that("fmutate miscellaneous", {
 
   expect_equal(
     fmutate(gmtc, a = mpg, b = a + hp + disp, c = cyl, hp = wt + carb, .keep = "none"),
-    dplyr::mutate(gmtc, a = mpg, b = a + hp + disp, c = cyl, hp = wt + carb, .keep = "none")
+    dplyr::transmute(gmtc, a = mpg, b = a + hp + disp, c = cyl, hp = wt + carb)
   )
 
   # Inconsistent with the above and also inefficient...
@@ -419,8 +457,26 @@ test_that("fmutate miscellaneous", {
     fmutate(mtcars, across(cyl:vs, data.table::shift))
   )
 
+  # Testing expressions turned into functions:
+  bcumsum = base::cumsum
+  lorentz_fun <- function(x) bcumsum(x) / bsum(x)
+  gmtc = mtc %>% roworder(mpg) %>% dplyr::group_by(cyl, vs, am)
+  expect_true(all_obj_equal(mtt(gmtc, lorentz_mpg = bcumsum(mpg) / bsum(mpg)),
+                            mtt(gmtc, lorentz_mpg = lorentz_fun(mpg)),
+                            mtt(gmtc, lorentz_mpg = fcumsum(mpg) / fsum(mpg)), # doesn't work because of global sorting...
+                            dplyr::mutate(gmtc, lorentz_mpg = bcumsum(mpg) / bsum(mpg))))
+
+  # Adding global variable:
+  q = 5
+  expect_true(all_obj_equal(mtt(gmtc, lorentz_mpg = bcumsum(mpg) / bsum(mpg) + q),
+                            mtt(gmtc, lorentz_mpg = lorentz_fun(mpg) + q),
+                            mtt(gmtc, lorentz_mpg = fcumsum(mpg) / fsum(mpg) + q),
+                            dplyr::mutate(gmtc, lorentz_mpg = bcumsum(mpg) / bsum(mpg) + q)))
+
 })
 
+}
+
 if(FALSE) {
 
 
@@ -443,3 +499,5 @@ if(FALSE) {
 
 
 }
+
+}
