@@ -1,7 +1,14 @@
 context("fvar and fsd")
 
-# rm(list = ls())
+if(!is.null(attributes(identical(FALSE, TRUE)))) stop("OECD label issue")
 
+bvar <- stats::var
+bsd <- stats::sd
+bsum <- base::sum
+
+
+# rm(list = ls())
+set.seed(101)
 x <- rnorm(100)
 w <- abs(100*rnorm(100))
 wdat <- abs(100*rnorm(32))
@@ -13,7 +20,7 @@ wNA[sample.int(100,20)] <- NA
 wdatNA[sample.int(32, 5)] <- NA
 f <- as.factor(sample.int(10, 100, TRUE))
 g <- GRP(mtcars, ~ cyl + vs + am)
-gf <- as.factor_GRP(g)
+gf <- as_factor_GRP(g)
 mtcNA <- na_insert(mtcars)
 mtcNA[27,1] <- NA # single group NA !!
 m <- as.matrix(mtcars)
@@ -34,7 +41,7 @@ wvar <- function(x, w, na.rm = FALSE) {
     # if(length(x) < 2L) return(NA_real_)
     w <- w[cc]
   } # else if(length(x) < 2L) return(if(is.na(x)) NA_real_ else 0)
-  sum(w*(x-weighted.mean(x,w))^2)/(sum(w)-1)
+  bsum(w*(x-weighted.mean(x,w))^2)/(bsum(w)-1)
 }
 
 wBY <- function(x, f, FUN, w, ...) {
@@ -47,39 +54,39 @@ wBY <- function(x, f, FUN, w, ...) {
 # fvar using Welford's Algoritm (default)
 
 test_that("fvar performs like base::var", {
-  expect_equal(fvar(NA), var(NA))
-  expect_equal(fvar(NA, na.rm = FALSE), var(NA))
-  expect_equal(fvar(1), var(1, na.rm = TRUE))
-  expect_equal(fvar(1:3), var(1:3, na.rm = TRUE))
-  expect_equal(fvar(-1:1), var(-1:1, na.rm = TRUE))
-  expect_equal(fvar(1, na.rm = FALSE), var(1))
-  expect_equal(fvar(1:3, na.rm = FALSE), var(1:3))
-  expect_equal(fvar(-1:1, na.rm = FALSE), var(-1:1))
-  expect_equal(fvar(x), var(x, na.rm = TRUE))
-  expect_equal(fvar(x, na.rm = FALSE), var(x))
-  expect_equal(fvar(xNA, na.rm = FALSE), var(xNA))
-  expect_equal(fvar(xNA), var(xNA, na.rm = TRUE))
+  expect_equal(fvar(NA), bvar(NA))
+  expect_equal(fvar(NA, na.rm = FALSE), bvar(NA))
+  expect_equal(fvar(1), bvar(1, na.rm = TRUE))
+  expect_equal(fvar(1:3), bvar(1:3, na.rm = TRUE))
+  expect_equal(fvar(-1:1), bvar(-1:1, na.rm = TRUE))
+  expect_equal(fvar(1, na.rm = FALSE), bvar(1))
+  expect_equal(fvar(1:3, na.rm = FALSE), bvar(1:3))
+  expect_equal(fvar(-1:1, na.rm = FALSE), bvar(-1:1))
+  expect_equal(fvar(x), bvar(x, na.rm = TRUE))
+  expect_equal(fvar(x, na.rm = FALSE), bvar(x))
+  expect_equal(fvar(xNA, na.rm = FALSE), bvar(xNA))
+  expect_equal(fvar(xNA), bvar(xNA, na.rm = TRUE))
   expect_equal(fvar(mtcars), fvar(m))
-  expect_equal(fvar(m), dapply(m, var, na.rm = TRUE))
-  expect_equal(fvar(m, na.rm = FALSE), dapply(m, var))
-  expect_equal(fvar(mNA, na.rm = FALSE), dapply(mNA, var))
-  expect_equal(fvar(mNA), dapply(mNA, var, na.rm = TRUE))
-  expect_equal(fvar(mtcars), dapply(mtcars, var, na.rm = TRUE))
-  expect_equal(fvar(mtcars, na.rm = FALSE), dapply(mtcars, var))
-  expect_equal(fvar(mtcNA, na.rm = FALSE), dapply(mtcNA, var))
-  expect_equal(fvar(mtcNA), dapply(mtcNA, var, na.rm = TRUE))
-  expect_equal(fvar(x, f), BY(x, f, var, na.rm = TRUE))
-  expect_equal(fvar(x, f, na.rm = FALSE), BY(x, f, var))
-  expect_equal(fvar(xNA, f, na.rm = FALSE), BY(xNA, f, var))
-  expect_equal(fvar(xNA, f), BY(xNA, f, var, na.rm = TRUE))
-  expect_equal(fvar(m, g), BY(m, g, var, na.rm = TRUE))
-  expect_equal(fvar(m, g, na.rm = FALSE), BY(m, g, var))
-  expect_equal(fvar(mNA, g, na.rm = FALSE), BY(mNA, g, var))
-  expect_equal(fvar(mNA, g), BY(mNA, g, var, na.rm = TRUE))
-  expect_equal(fvar(mtcars, g), BY(mtcars, g, var, na.rm = TRUE))
-  expect_equal(fvar(mtcars, g, na.rm = FALSE), BY(mtcars, g, var))
-  expect_equal(fvar(mtcNA, g, na.rm = FALSE), BY(mtcNA, g, var))
-  expect_equal(fvar(mtcNA, g), BY(mtcNA, g, var, na.rm = TRUE))
+  expect_equal(fvar(m), dapply(m, bvar, na.rm = TRUE))
+  expect_equal(fvar(m, na.rm = FALSE), dapply(m, bvar))
+  expect_equal(fvar(mNA, na.rm = FALSE), dapply(mNA, bvar))
+  expect_equal(fvar(mNA), dapply(mNA, bvar, na.rm = TRUE))
+  expect_equal(fvar(mtcars), dapply(mtcars, bvar, na.rm = TRUE))
+  expect_equal(fvar(mtcars, na.rm = FALSE), dapply(mtcars, bvar))
+  expect_equal(fvar(mtcNA, na.rm = FALSE), dapply(mtcNA, bvar))
+  expect_equal(fvar(mtcNA), dapply(mtcNA, bvar, na.rm = TRUE))
+  expect_equal(fvar(x, f), BY(x, f, bvar, na.rm = TRUE))
+  expect_equal(fvar(x, f, na.rm = FALSE), BY(x, f, bvar))
+  expect_equal(fvar(xNA, f, na.rm = FALSE), BY(xNA, f, bvar))
+  expect_equal(fvar(xNA, f), BY(xNA, f, bvar, na.rm = TRUE))
+  expect_equal(fvar(m, g), BY(m, g, bvar, na.rm = TRUE))
+  expect_equal(fvar(m, g, na.rm = FALSE), BY(m, g, bvar))
+  expect_equal(fvar(mNA, g, na.rm = FALSE), BY(mNA, g, bvar))
+  expect_equal(fvar(mNA, g), BY(mNA, g, bvar, na.rm = TRUE))
+  expect_equal(fvar(mtcars, g), BY(mtcars, g, bvar, na.rm = TRUE))
+  expect_equal(fvar(mtcars, g, na.rm = FALSE), BY(mtcars, g, bvar))
+  expect_equal(fvar(mtcNA, g, na.rm = FALSE), BY(mtcNA, g, bvar))
+  expect_equal(fvar(mtcNA, g), BY(mtcNA, g, bvar, na.rm = TRUE))
 })
 
 test_that("fvar with weights performs as intended (unbiased)", {
@@ -398,39 +405,39 @@ test_that("fvar produces errors for wrong input", {
 
 
 test_that("fvar with direct algorithm performs like base::var", {
-  expect_equal(fvar(NA, stable.algo = FALSE), var(NA))
-  expect_equal(fvar(NA, na.rm = FALSE, stable.algo = FALSE), var(NA))
-  expect_equal(fvar(1, stable.algo = FALSE), var(1, na.rm = TRUE))
-  expect_equal(fvar(1:3, stable.algo = FALSE), var(1:3, na.rm = TRUE))
-  expect_equal(fvar(-1:1, stable.algo = FALSE), var(-1:1, na.rm = TRUE))
-  expect_equal(fvar(1, na.rm = FALSE, stable.algo = FALSE), var(1))
-  expect_equal(fvar(1:3, na.rm = FALSE, stable.algo = FALSE), var(1:3))
-  expect_equal(fvar(-1:1, na.rm = FALSE, stable.algo = FALSE), var(-1:1))
-  expect_equal(fvar(x, stable.algo = FALSE), var(x, na.rm = TRUE))
-  expect_equal(fvar(x, na.rm = FALSE, stable.algo = FALSE), var(x))
-  expect_equal(fvar(xNA, na.rm = FALSE, stable.algo = FALSE), var(xNA))
-  expect_equal(fvar(xNA, stable.algo = FALSE), var(xNA, na.rm = TRUE))
+  expect_equal(fvar(NA, stable.algo = FALSE), bvar(NA))
+  expect_equal(fvar(NA, na.rm = FALSE, stable.algo = FALSE), bvar(NA))
+  expect_equal(fvar(1, stable.algo = FALSE), bvar(1, na.rm = TRUE))
+  expect_equal(fvar(1:3, stable.algo = FALSE), bvar(1:3, na.rm = TRUE))
+  expect_equal(fvar(-1:1, stable.algo = FALSE), bvar(-1:1, na.rm = TRUE))
+  expect_equal(fvar(1, na.rm = FALSE, stable.algo = FALSE), bvar(1))
+  expect_equal(fvar(1:3, na.rm = FALSE, stable.algo = FALSE), bvar(1:3))
+  expect_equal(fvar(-1:1, na.rm = FALSE, stable.algo = FALSE), bvar(-1:1))
+  expect_equal(fvar(x, stable.algo = FALSE), bvar(x, na.rm = TRUE))
+  expect_equal(fvar(x, na.rm = FALSE, stable.algo = FALSE), bvar(x))
+  expect_equal(fvar(xNA, na.rm = FALSE, stable.algo = FALSE), bvar(xNA))
+  expect_equal(fvar(xNA, stable.algo = FALSE), bvar(xNA, na.rm = TRUE))
   expect_equal(fvar(mtcars, stable.algo = FALSE), fvar(m))
-  expect_equal(fvar(m, stable.algo = FALSE), dapply(m, var, na.rm = TRUE))
-  expect_equal(fvar(m, na.rm = FALSE, stable.algo = FALSE), dapply(m, var))
-  expect_equal(fvar(mNA, na.rm = FALSE, stable.algo = FALSE), dapply(mNA, var))
-  expect_equal(fvar(mNA, stable.algo = FALSE), dapply(mNA, var, na.rm = TRUE))
-  expect_equal(fvar(mtcars, stable.algo = FALSE), dapply(mtcars, var, na.rm = TRUE))
-  expect_equal(fvar(mtcars, na.rm = FALSE, stable.algo = FALSE), dapply(mtcars, var))
-  expect_equal(fvar(mtcNA, na.rm = FALSE, stable.algo = FALSE), dapply(mtcNA, var))
-  expect_equal(fvar(mtcNA, stable.algo = FALSE), dapply(mtcNA, var, na.rm = TRUE))
-  expect_equal(fvar(x, f, stable.algo = FALSE), BY(x, f, var, na.rm = TRUE))
-  expect_equal(fvar(x, f, na.rm = FALSE, stable.algo = FALSE), BY(x, f, var))
-  expect_equal(fvar(xNA, f, na.rm = FALSE, stable.algo = FALSE), BY(xNA, f, var))
-  expect_equal(fvar(xNA, f, stable.algo = FALSE), BY(xNA, f, var, na.rm = TRUE)) # failed?
-  # expect_equal(fvar(m, g, stable.algo = FALSE), BY(m, g, var, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(m, g, na.rm = FALSE, stable.algo = FALSE), BY(m, g, var)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(mNA, g, na.rm = FALSE, stable.algo = FALSE), BY(mNA, g, var)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(mNA, g, stable.algo = FALSE), BY(mNA, g, var, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(mtcars, g, stable.algo = FALSE), BY(mtcars, g, var, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(mtcars, g, na.rm = FALSE, stable.algo = FALSE), BY(mtcars, g, var)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(mtcNA, g, na.rm = FALSE, stable.algo = FALSE), BY(mtcNA, g, var)) # failed on arch i386 CMD check and patched-solaris-x86
-  # expect_equal(fvar(mtcNA, g, stable.algo = FALSE), BY(mtcNA, g, var, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
+  expect_equal(fvar(m, stable.algo = FALSE), dapply(m, bvar, na.rm = TRUE))
+  expect_equal(fvar(m, na.rm = FALSE, stable.algo = FALSE), dapply(m, bvar))
+  expect_equal(fvar(mNA, na.rm = FALSE, stable.algo = FALSE), dapply(mNA, bvar))
+  expect_equal(fvar(mNA, stable.algo = FALSE), dapply(mNA, bvar, na.rm = TRUE))
+  expect_equal(fvar(mtcars, stable.algo = FALSE), dapply(mtcars, bvar, na.rm = TRUE))
+  expect_equal(fvar(mtcars, na.rm = FALSE, stable.algo = FALSE), dapply(mtcars, bvar))
+  expect_equal(fvar(mtcNA, na.rm = FALSE, stable.algo = FALSE), dapply(mtcNA, bvar))
+  expect_equal(fvar(mtcNA, stable.algo = FALSE), dapply(mtcNA, bvar, na.rm = TRUE))
+  expect_equal(fvar(x, f, stable.algo = FALSE), BY(x, f, bvar, na.rm = TRUE))
+  expect_equal(fvar(x, f, na.rm = FALSE, stable.algo = FALSE), BY(x, f, bvar))
+  expect_equal(fvar(xNA, f, na.rm = FALSE, stable.algo = FALSE), BY(xNA, f, bvar))
+  expect_equal(fvar(xNA, f, stable.algo = FALSE), BY(xNA, f, bvar, na.rm = TRUE)) # failed?
+  # expect_equal(fvar(m, g, stable.algo = FALSE), BY(m, g, bvar, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(m, g, na.rm = FALSE, stable.algo = FALSE), BY(m, g, bvar)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(mNA, g, na.rm = FALSE, stable.algo = FALSE), BY(mNA, g, bvar)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(mNA, g, stable.algo = FALSE), BY(mNA, g, bvar, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(mtcars, g, stable.algo = FALSE), BY(mtcars, g, bvar, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(mtcars, g, na.rm = FALSE, stable.algo = FALSE), BY(mtcars, g, bvar)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(mtcNA, g, na.rm = FALSE, stable.algo = FALSE), BY(mtcNA, g, bvar)) # failed on arch i386 CMD check and patched-solaris-x86
+  # expect_equal(fvar(mtcNA, g, stable.algo = FALSE), BY(mtcNA, g, bvar, na.rm = TRUE)) # failed on arch i386 CMD check and patched-solaris-x86
 })
 
 test_that("fvar with with direct algorithm and weights performs as intended (unbiased)", {
@@ -748,39 +755,39 @@ test_that("fvar with direct algorithm produces errors for wrong input", {
 # fsd (not necessary to test in the same way because it's just sqrt(fvar()))
 
 test_that("fsd performs like base::sd", {
-  expect_equal(fsd(NA), sd(NA))
-  expect_equal(fsd(NA, na.rm = FALSE), sd(NA))
-  expect_equal(fsd(1), sd(1, na.rm = TRUE))
-  expect_equal(fsd(1:3), sd(1:3, na.rm = TRUE))
-  expect_equal(fsd(-1:1), sd(-1:1, na.rm = TRUE))
-  expect_equal(fsd(1, na.rm = FALSE), sd(1))
-  expect_equal(fsd(1:3, na.rm = FALSE), sd(1:3))
-  expect_equal(fsd(-1:1, na.rm = FALSE), sd(-1:1))
-  expect_equal(fsd(x), sd(x, na.rm = TRUE))
-  expect_equal(fsd(x, na.rm = FALSE), sd(x))
-  expect_equal(fsd(xNA, na.rm = FALSE), sd(xNA))
-  expect_equal(fsd(xNA), sd(xNA, na.rm = TRUE))
+  expect_equal(fsd(NA), bsd(NA))
+  expect_equal(fsd(NA, na.rm = FALSE), bsd(NA))
+  expect_equal(fsd(1), bsd(1, na.rm = TRUE))
+  expect_equal(fsd(1:3), bsd(1:3, na.rm = TRUE))
+  expect_equal(fsd(-1:1), bsd(-1:1, na.rm = TRUE))
+  expect_equal(fsd(1, na.rm = FALSE), bsd(1))
+  expect_equal(fsd(1:3, na.rm = FALSE), bsd(1:3))
+  expect_equal(fsd(-1:1, na.rm = FALSE), bsd(-1:1))
+  expect_equal(fsd(x), bsd(x, na.rm = TRUE))
+  expect_equal(fsd(x, na.rm = FALSE), bsd(x))
+  expect_equal(fsd(xNA, na.rm = FALSE), bsd(xNA))
+  expect_equal(fsd(xNA), bsd(xNA, na.rm = TRUE))
   expect_equal(fsd(mtcars), fsd(m))
-  expect_equal(fsd(m), dapply(m, sd, na.rm = TRUE))
-  expect_equal(fsd(m, na.rm = FALSE), dapply(m, sd))
-  expect_equal(fsd(mNA, na.rm = FALSE), dapply(mNA, sd))
-  expect_equal(fsd(mNA), dapply(mNA, sd, na.rm = TRUE))
-  expect_equal(fsd(mtcars), dapply(mtcars, sd, na.rm = TRUE))
-  expect_equal(fsd(mtcars, na.rm = FALSE), dapply(mtcars, sd))
-  expect_equal(fsd(mtcNA, na.rm = FALSE), dapply(mtcNA, sd))
-  expect_equal(fsd(mtcNA), dapply(mtcNA, sd, na.rm = TRUE))
-  expect_equal(fsd(x, f), BY(x, f, sd, na.rm = TRUE))
-  expect_equal(fsd(x, f, na.rm = FALSE), BY(x, f, sd))
-  expect_equal(fsd(xNA, f, na.rm = FALSE), BY(xNA, f, sd))
-  expect_equal(fsd(xNA, f), BY(xNA, f, sd, na.rm = TRUE))
-  expect_equal(fsd(m, g), BY(m, g, sd, na.rm = TRUE))
-  expect_equal(fsd(m, g, na.rm = FALSE), BY(m, g, sd))
-  expect_equal(fsd(mNA, g, na.rm = FALSE), BY(mNA, g, sd))
-  expect_equal(fsd(mNA, g), BY(mNA, g, sd, na.rm = TRUE))
-  expect_equal(fsd(mtcars, g), BY(mtcars, g, sd, na.rm = TRUE))
-  expect_equal(fsd(mtcars, g, na.rm = FALSE), BY(mtcars, g, sd))
-  expect_equal(fsd(mtcNA, g, na.rm = FALSE), BY(mtcNA, g, sd))
-  expect_equal(fsd(mtcNA, g), BY(mtcNA, g, sd, na.rm = TRUE))
+  expect_equal(fsd(m), dapply(m, bsd, na.rm = TRUE))
+  expect_equal(fsd(m, na.rm = FALSE), dapply(m, bsd))
+  expect_equal(fsd(mNA, na.rm = FALSE), dapply(mNA, bsd))
+  expect_equal(fsd(mNA), dapply(mNA, bsd, na.rm = TRUE))
+  expect_equal(fsd(mtcars), dapply(mtcars, bsd, na.rm = TRUE))
+  expect_equal(fsd(mtcars, na.rm = FALSE), dapply(mtcars, bsd))
+  expect_equal(fsd(mtcNA, na.rm = FALSE), dapply(mtcNA, bsd))
+  expect_equal(fsd(mtcNA), dapply(mtcNA, bsd, na.rm = TRUE))
+  expect_equal(fsd(x, f), BY(x, f, bsd, na.rm = TRUE))
+  expect_equal(fsd(x, f, na.rm = FALSE), BY(x, f, bsd))
+  expect_equal(fsd(xNA, f, na.rm = FALSE), BY(xNA, f, bsd))
+  expect_equal(fsd(xNA, f), BY(xNA, f, bsd, na.rm = TRUE))
+  expect_equal(fsd(m, g), BY(m, g, bsd, na.rm = TRUE))
+  expect_equal(fsd(m, g, na.rm = FALSE), BY(m, g, bsd))
+  expect_equal(fsd(mNA, g, na.rm = FALSE), BY(mNA, g, bsd))
+  expect_equal(fsd(mNA, g), BY(mNA, g, bsd, na.rm = TRUE))
+  expect_equal(fsd(mtcars, g), BY(mtcars, g, bsd, na.rm = TRUE))
+  expect_equal(fsd(mtcars, g, na.rm = FALSE), BY(mtcars, g, bsd))
+  expect_equal(fsd(mtcNA, g, na.rm = FALSE), BY(mtcNA, g, bsd))
+  expect_equal(fsd(mtcNA, g), BY(mtcNA, g, bsd, na.rm = TRUE))
 })
 
 test_that("fsd performs numerically stable", {
